CONSENSYS // Multi-Agent Code Review

## > INPUT_CODE

--quick --stream
0 chars

PIPELINE_RUNNING

multi-agent code review

00:00
[--:--:--] [INIT] Starting code review pipeline...

## > VERDICT

0

APPROVE

0

REJECT

0

ABSTAIN

### [!] KEY_ISSUES

### [+] SUGGESTIONS

## > EXPORT

## > SHARE_RESULTS

Shareable Link:
QR Code (scan to share):

Anyone with this link can view the review results (read-only).

## > SUGGESTED_FIXES

### [!!] CRITICAL 0

### [!] HIGH 0

### [*] MEDIUM 0

### [-] LOW 0

[OK] NO_FIXES_REQUIRED

all agents found code acceptable

## > PATTERNS_DETECTED

// common security patterns detected - click to view fixes and documentation

## > PATCHED_CODE

// code with all suggested fixes applied

### [+] APPLIED_FIXES

## > AGENT_REVIEWS

## > AGENT_DISCUSSION

## > AGENT_VOTES

## > REVIEW_HISTORY

## > KEYBOARD_SHORTCUTS

### // ACTIONS

Submit code for review `⌘/Ctrl + Enter`
Clear input & focus `⌘/Ctrl + K`
Show export options `⌘/Ctrl + E`
Toggle dark/light mode `⌘/Ctrl + D`
Toggle sound effects `⌘/Ctrl + M`

### // NAVIGATION

Jump to Input `⌘/Ctrl + 1`
Jump to Reviews `⌘/Ctrl + 2`
Jump to Fixes `⌘/Ctrl + 3`
Jump to Consensus `⌘/Ctrl + 4`

### // OTHER

Show shortcuts (this menu) `?`
Close modal / Escape `Esc`